com_SS2_SS3_non_predators: Taxa abundances for non-predatory insects at the second and...

Description Usage Format Source

Description

A dataset containing the abundances of the non predatory insects (herbivores and detritivores) that were present in the second and third surveys.

Usage

1

Format

A data frame with 44 rows or 'observations' and 16 variables or 'taxa':

Experimental Data


RodolfoPelinson/PredatorIsolationStochasticity documentation built on Feb. 21, 2022, 12:03 p.m.